@@ -1,7 +1,7 @@
 package Perinci::Sub::Normalize;
 
-our $DATE = '2016-04-12'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2016-05-10'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -141,11 +141,10 @@ sub normalize_function_metadata($;$) {
     $opts->{normalize_sah_schemas}       //= 1;
     $opts->{remove_internal_properties}  //= 0;
 
-    require Sah::Schema::Rinci;
-    my $sch = $Sah::Schema::Rinci::SCHEMAS{rinci_function}
-        or die "BUG: Rinci schema structure changed (1)";
+    require Sah::Schema::rinci::function_meta;
+    my $sch = $Sah::Schema::rinci::function_meta::schema;
     my $sch_proplist = $sch->[1]{_prop}
-        or die "BUG: Rinci schema structure changed (2)";
+        or die "BUG: Rinci schema structure changed (1a)";
 
     _normalize($meta, 1.1, $opts, $sch_proplist, {}, '');
 }
@@ -165,7 +164,7 @@ Perinci::Sub::Normalize - Normalize Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.16 of Perinci::Sub::Normalize (from Perl distribution Perinci-Sub-Normalize), released on 2016-04-12.
+This document describes version 0.17 of Perinci::Sub::Normalize (from Perl distribution Perinci-Sub-Normalize), released on 2016-05-10.
 
 =head1 SYNOPSIS
 
